<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
    xmlns:xs="http://www.w3.org/2001/XMLSchema"
    exclude-result-prefixes="xs"
    version="2.0">
    
    <xsl:output method="html"
                encoding="UTF-8"
                omit-xml-declaration="yes"
                indent="yes"               
                version="5.0"   
    />
    
    
    <xsl:template match="/">
        <html>
            <head>
                <title><xsl:value-of select="/pressRelease/metadata/title"/></title>
                <link rel="stylesheet" type="text/css" href="press_release_style.css"/>
            </head>
            <body>
               
                <xsl:apply-templates/>
                <br/>
                <!-- Print copyright information out of order at bottom of document -->
                <!-- Note that I am not using the "Copyright" text or copyright symbol that
                    are included in the element as mixed content.  By this point, I have
                    decided that including them in the content document was a bad idea. 
                    So, I am just inserting them here as part of my template text.  The
                    next time I teach this course I will revise the source XML document
                    to reflect these changes.
                -->
                <h4>
                    Copyright © 
                    <xsl:value-of select="/pressRelease/metadata/copyright/yearOfPublication"/>
                    <xsl:text> </xsl:text>
                    <a href="{/pressRelease/metadata/copyright/publisher/@URL}" class="portalLink">
                        <xsl:value-of select="/pressRelease/metadata/copyright/publisher"/>
                    </a>
                </h4>
                
            </body>
        </html>

    </xsl:template>
    
    <xsl:template match="title">
        <h2><xsl:value-of select="."></xsl:value-of></h2>  
    </xsl:template>
    
    <xsl:template match="author">
        <h4>by <xsl:apply-templates/></h4>  
    </xsl:template>
    
    
    <!-- Note that the empty element xsl:template below catches elements
        of type placeOfPublication.  Having caught them, it suppresses them 
        by specifying no action.  Most notably, there is not xsl:apply-templates
        included in this template that would restart navigation.  -->
    <xsl:template match="placeOfPublication"/>

    
    <xsl:template match="copyright"/>
    
    <!-- Note that the template rule below matches only the first paragraph.  Having
        done that, it inserts the text for the placeOfPublication (which we have suppressed
        from appearing in its naturally occurring order. -->
    <xsl:template match="p[1]">
        <b><xsl:value-of select="/pressRelease/metadata/placeOfPublication"/></b>
        <xsl:text> - </xsl:text>
        <xsl:apply-templates/>
    </xsl:template>
    
    <xsl:template match="p">
        <p>
            <xsl:apply-templates/>
        </p>
    </xsl:template>
    
    
    <!-- Note that I used the "|" character in the XPATH expression below.  You
        can read it as "OR". This allows one template to be used for three separate
        element types.  Wanted to do the same thing for more than one element is
        a fairly common use case. -->
    <xsl:template match="person | institution | program">
        <a href="{@URL}"  class="portalLink"><xsl:value-of select="."/></a>
    </xsl:template>


</xsl:stylesheet>